@@ -1,20 +1,25 @@
 package Mail::Milter::Authentication::Extra;
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v1.1.5');
+use Mail::Milter::Authentication 2;
+our $VERSION = '2.20180318'; # VERSION
+# ABSTRACT: Extra handlers for Authentication Milter
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Mail::Milter::Authentication::Extra - A Perl Mail Authentication Milter extra handler modules
+Mail::Milter::Authentication::Extra - Extra handlers for Authentication Milter
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-Additional handlers for Authentication Milter which did not fit within the core functionality, or
-are not yet 100% production ready.
+version 2.20180318
 
 =head1 SYNOPSIS
 
@@ -22,6 +27,11 @@ This is a collection of additional handler modules for Authentication Milter.
 
 Please see the output of 'authentication_milter --help' for usage help.
 
+=head1 DESCRIPTION
+
+Additional handlers for Authentication Milter which did not fit within the core functionality, or
+are not yet 100% production ready.
+
 =head1 DEPENDENCIES
 
   Mail::Milter::Authentication
@@ -29,13 +39,15 @@ Please see the output of 'authentication_milter --help' for usage help.
   Mail::SpamAssassin::Client
   DB_File
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marc Bradshaw E<lt>marc@marcbradshaw.netE<gt>
+Marc Bradshaw <marc@marcbradshaw.net>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2017
+This software is copyright (c) 2018 by Marc Bradshaw.
 
-This library is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
