@@ -2,12 +2,16 @@ package Mail::Milter::Authentication::Handler::RSpamD;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v1.1.5');
+our $VERSION = '2.20180318'; # VERSION
+# #ABSTRACT: RSpamD scanning for Authentication Milter
 
 use English qw{ -no_match_vars };
 use Sys::Syslog qw{:standard :macros};
 use HTTP::Tiny;
 use JSON;
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 use Data::Dumper;
 
@@ -168,7 +172,8 @@ sub eom_callback {
     my $response = $http->post( "http://$host:$port/check", { 'headers' => $headers, 'content' => $message } );
     if ( ! $response->{'success'} ) {
         $self->log_error( 'RSpamD could not connect to server - ' . $response->{'status'} . ' - ' . $response->{'reason'} . ' - ' . $response->{'content'} );
-        $self->add_auth_header('x-rspam=temperror');
+        my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-rspam' )->safe_set_value( 'temperror' );
+        $self->add_auth_header( $header );
         $self->{ 'metrics_data' }->{ 'result' } = 'servererror';
         $self->metric_count( 'rspamd_total', $self->{ 'metrics_data' } );
         return;
@@ -178,7 +183,8 @@ sub eom_callback {
     my $rspamd_data = eval{ $j->decode( $response->{'content'} ); };
     if ( ! exists( $rspamd_data->{'default'} ) ) {
         $self->log_error( 'RSpamD bad data from server' );
-        $self->add_auth_header('x-rspam=temperror');
+        my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-rspam' )->safe_set_value( 'temperror' );
+        $self->add_auth_header( $header );
         $self->{ 'metrics_data' }->{ 'result' } = 'serverdataerror';
         $self->metric_count( 'rspamd_total', $self->{ 'metrics_data' } );
         return;
@@ -212,16 +218,9 @@ sub eom_callback {
     $self->prepend_header( 'X-Spam-Status', $status );
     $self->prepend_header( 'X-Spam-Action', $action );
 
-    my $header = join(
-        q{ },
-        $self->format_header_entry(
-            'x-rspam',
-            ( $spam->{'is_spam'} eq 0 ? 'pass' : 'fail' ),
-        ),
-        $self->format_header_entry( 'score',    sprintf ( '%.02f', $spam->{'score'} ) ),
-        $self->format_header_entry( 'required', sprintf ( '%.02f', $spam->{'required_score'} ) ),
-    );
-
+    my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-rspam' )->safe_set_value( ( $spam->{'is_spam'} eq 0 ? 'pass' : 'fail' ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'score' )->safe_set_value( sprintf ( '%.02f', $spam->{'score'} ) ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'required' )->safe_set_value( sprintf ( '%.02f', $spam->{'required_score'} ) ) );
     $self->add_auth_header($header);
 
     $self->{ 'metrics_data' }->{ 'result' } = ( $spam->{'is_spam'} eq 0 ? 'pass' : 'fail' );
@@ -258,9 +257,17 @@ sub close_callback {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-  Authentication Milter - RSpamD Module
+Mail::Milter::Authentication::Handler::RSpamD
+
+=head1 VERSION
+
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -276,8 +283,6 @@ Check email for spam using rspamd.
             "remove_headers" : "yes"
         },
 
-=head1 SYNOPSIS
-
 =head2 CONFIG
 
 Add a block to the handlers section of your config as follows.
@@ -290,16 +295,15 @@ Add a block to the handlers section of your config as follows.
             "remove_headers" : "yes"
         },
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marc Bradshaw E<lt>marc@marcbradshaw.netE<gt>
+Marc Bradshaw <marc@marcbradshaw.net>
 
-=head1 COPYRIGHT
-
-Copyright 2017
-
-This library is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2018 by Marc Bradshaw.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
