@@ -2,10 +2,14 @@ package Mail::Milter::Authentication::Handler::SpamAssassin;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v1.1.5');
+our $VERSION = '2.20180318'; # VERSION
+# ABSTRACT: SpamAssassin scanner for Authentication Milter
 
 use English qw{ -no_match_vars };
 use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 
 use Mail::SpamAssassin;
 use Mail::SpamAssassin::Client;
@@ -147,7 +151,8 @@ sub eom_callback {
 
     if ( ! $sa_client->ping() ) {
         $self->log_error( 'SpamAssassin could not connect to server' );
-        $self->add_auth_header('x-spam=temperror');
+        my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-spam' )->safe_set_value( 'temperror' );
+        $self->add_auth_header( $header );
         $self->{ 'metrics_data' }->{ 'result' } = 'servererror';
         $self->metric_count( 'spamassassin_total', $self->{ 'metrics_data' } );
         return;
@@ -190,16 +195,9 @@ sub eom_callback {
     $self->prepend_header( 'X-Spam-Status', $status );
     $self->prepend_header( 'X-Spam-hits',   $hits );
 
-    my $header = join(
-        q{ },
-        $self->format_header_entry(
-            'x-spam',
-            ( $sa_status->{'isspam'} eq 'False' ? 'pass' : 'fail' ),
-        ),
-        $self->format_header_entry( 'score',    sprintf ( '%.02f', $sa_status->{'score'} ) ),
-        $self->format_header_entry( 'required', sprintf ( '%.02f', $sa_status->{'threshold'} ) ),
-    );
-
+    my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-spam' )->safe_set_value( ( $sa_status->{'isspam'} eq 'False' ? 'pass' : 'fail' ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'score' )->safe_set_value( sprintf ( '%.02f', $sa_status->{'score'} ) ) );
+    $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'required' )->safe_set_value( sprintf ( '%.02f', $sa_status->{'threshold'} ) ) );
     $self->add_auth_header($header);
 
     $self->{ 'metrics_data' }->{ 'result' } = ( $sa_status->{'isspam'} eq 'False' ? 'pass' : 'fail' );
@@ -245,9 +243,17 @@ sub close_callback {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-  Authentication Milter - SpamAssassin Module
+Mail::Milter::Authentication::Handler::SpamAssassin - SpamAssassin scanner for Authentication Milter
+
+=head1 VERSION
+
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -263,8 +269,6 @@ Check email for spam using SpamAssassin spamd.
             "remove_headers" : "yes"
         },
 
-=head1 SYNOPSIS
-
 =head2 CONFIG
 
 Add a block to the handlers section of your config as follows.
@@ -277,15 +281,15 @@ Add a block to the handlers section of your config as follows.
             "remove_headers" : "yes"
         },
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marc Bradshaw E<lt>marc@marcbradshaw.netE<gt>
+Marc Bradshaw <marc@marcbradshaw.net>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2017
-
-This library is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
