@@ -4,8 +4,12 @@ use warnings;
 use DB_File;
 use Mail::Milter::Authentication::Handler::UserDB::Hash;
 use Sys::Syslog qw{:standard :macros};
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v1.1.5');
+our $VERSION = '2.20180318'; # VERSION
+# ABSTRACT: Check inbound mail against a user list
 
 my $CHECKED_TIME;
 
@@ -49,7 +53,8 @@ sub eoh_callback {
     if ( $self->{'local_user'} ) {
         $self->metric_count( 'userdb_total', { 'result' => 'pass' } );
         if ( $config->{'add_header'} ) {
-            $self->add_auth_header('x-local-user=pass');
+            my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'x-local-user' )->safe_set_value( 'pass' );
+            $self->add_auth_header( $header );
         }
     }
     else {
@@ -119,9 +124,17 @@ sub get_user_from_address {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-  Authentication Milter - UserDB Module
+Mail::Milter::Authentication::Handler::UserDB - Check inbound mail against a user list
+
+=head1 VERSION
+
+version 2.20180318
 
 =head1 DESCRIPTION
 
@@ -134,8 +147,6 @@ Check if email has a local recipient account.
             "lookup" : [ "hash:/etc/postfix/virtusertable" ]
         },
 
-=head1 SYNOPSIS
-
 =head2 CONFIG
 
 Add a block to the handlers section of your config as follows.
@@ -145,16 +156,15 @@ Add a block to the handlers section of your config as follows.
             "lookup"     : [ "hash:/etc/postfix/virtusertable" ]
         },
 
+=head1 AUTHOR
 
-=head1 AUTHORS
+Marc Bradshaw <marc@marcbradshaw.net>
 
-Marc Bradshaw E<lt>marc@marcbradshaw.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT
-
-Copyright 2017
-
-This library is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+This software is copyright (c) 2018 by Marc Bradshaw.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
