@@ -2,7 +2,8 @@ package Mail::Milter::Authentication::Handler::UserDB::Hash;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler::UserDB';
-use version; our $VERSION = version->declare('v1.1.4');
+our $VERSION = '2.20180318'; # VERSION
+# ABSTRACT: Hash table based userdb provider
 
 use DB_File;
 
@@ -88,3 +89,30 @@ sub check_table {
 
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::Milter::Authentication::Handler::UserDB::Hash - Hash table based userdb provider
+
+=head1 VERSION
+
+version 2.20180318
+
+=head1 AUTHOR
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Marc Bradshaw.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
